//
// QPerforce is a gui interface to the perforce revision control
// system. It is based on the qt library, and should be easily portable
// across any platform that has this toolkit available.
// 
// Copyright (C) 2002 Jacob Gladish
// 
//
#ifndef __VIEW_MENU_H__
#define __VIEW_MENU_H__

#include <qpopupmenu.h>

class QCheckBox;

class ViewMenu  : public QPopupMenu
{
  Q_OBJECT

public:	
  
	ViewMenu( QWidget* parent = 0, const char* name = 0 );
	virtual ~ViewMenu();

  inline int getViewUsersId( void ) const;
  inline int getViewSubmittedChangeListsId( void ) const;
  inline int getViewBranchSpecId( void ) const;
  inline int getViewJobsId( void ) const;
  inline int getViewLabelsId( void ) const;

public slots:

	void slotRefreshActivePane();
	void slotViewWarningsAndErrors();

	void slotOrganizeBookmarks();
	void slotAddBoomark();

	void slotShowStatusBar();
	void slotShowToolBar();

	void slotClearFilter();
	void slotFilterDepot();

	void slotEntireDepot();
	void slotLocalViewOfClientTree();
	void slotLocalViewOfDepot();
	void slotClientViewOfDepot();
  		
	void slotPendingChangelists();
	void slotClientSpecs();	

private:

  int _usersId;

  QPopupMenu* _changeLists;
  QPopupMenu* _bookMarks;

  int _showToolBarId;
  int _showStatusBarId;
  int _showSubmittedChangeListsId;
  int _showBranchSpecId;
  int _showJobsId;
  int _showLabelsId;
};

inline int ViewMenu::getViewUsersId( void ) const
{
  return _usersId;
}

inline int ViewMenu::getViewSubmittedChangeListsId( void ) const
{
  return _showSubmittedChangeListsId;
}

inline int ViewMenu::getViewBranchSpecId( void ) const
{
  return _showBranchSpecId;
}


inline int ViewMenu::getViewJobsId( void ) const
{
  return _showJobsId;
}

inline int ViewMenu::getViewLabelsId( void ) const
{
  return _showLabelsId;
}


#endif
